Module auth

Module auth 

Functions

gcp_get_authentication_method
Below function uses type of authentication to GCP account you want to use - you can choose either
gcp_get_credentials_token_iam
Below function uses current system log in credentials obtained via gcloud auth login command
gcp_get_credentials_token_sa
Below function uses Service Account credentials to generate token