create_gcp_vm

Function create_gcp_vm 

pub async fn create_gcp_vm(
    token: String,
    project_name: String,
    gcp_vm_zone: String,
    gcp_vm_specs: CreateVM,
) -> Result<(), Error>
Create GCP VM instance External and internal IP available via Option Token, project name, net and subnet name and tags need to be provided