cipher

Function cipher 

pub fn cipher(
    server_pub_key: &Path,
    client_secret_key: &Path,
    nonce_secret_key: &Path,
    msg: &[u8],
) -> Result<Vec<u8>, Error>
Encrypt function Server pub key, client secret key and nonce key paths need to be provided Message is formatted as u8