Module log_parser

Module log_parser 

Functions

gke_log_parser
Function which parse logs from k8s and send notifications to Slack channel on every match Token, project, k8s data and slack data need to be provided
gke_log_parser_loop
Log parser loop with error handling and reconnecting