gke_log_parser

Function gke_log_parser 

pub async fn gke_log_parser(
    token: String,
    project_name: String,
    gke_cluster_endpoint: String,
    gke_cluster_namespace: String,
    gke_cluster_region: String,
    gke_k8s_hostname: String,
    gke_log_message: Vec<String>,
    slack_webhook_url: String,
    slack_channel: String,
    slack_username: String,
    slack_message_text: String,
    slack_notified_users: Vec<String>,
    slack_icon_emoji: String,
) -> Result<(), Box<dyn Error>>
Function which parse logs from k8s and send notifications to Slack channel on every match Token, project, k8s data and slack data need to be provided