Module calculated

Module calculated 

Functions

cpu_calculated_stg_cfgroup1
Function to calculate used cpu - based on cpu cycles on cfgroup1 config in nodepool Amount of requested CPU needs to be provided as well as other gke data
cpu_calculated_stg_cfgroup2
Function to calculate used cpu - based on cpu cycles on cfgroup2 config in nodepool Amount of requested CPU needs to be provided as well as other gke data