Module vm_remote

Module vm_remote 

Functions

exec_command_on_remote
Function to interact with remote server
exec_command_on_remote_cli
Function to interact with remote server via cli Host and Commands are Vec Additional arguments are separated by “,”