Functions
- gcp_
get_ authentication_ method - Below function uses type of authentication to GCP account you want to use - you can choose either
- gcp_
get_ credentials_ token_ iam - Below function uses current system log in credentials obtained via gcloud auth login command
- gcp_
get_ credentials_ token_ sa - Below function uses Service Account credentials to generate token