pub fn decipher(
server_secret_key: &Path,
client_pub_key: &Path,
nonce_secret_key: &Path,
msg: &[u8],
) -> Result<String, Error>Expand description
Decrypt function Server secret key, client pub key and nonce key paths need to be provided Message is formatted as u8