Functions
- gke_
log_ parser - Function which parse logs from k8s and send notifications to Slack channel on every match Token, project, k8s data and slack data need to be provided
- gke_
log_ parser_ loop - Log parser loop with error handling and reconnecting