Functions
- cpu_
calculated_ stg_ cfgroup1 - Function to calculate used cpu - based on cpu cycles on cfgroup1 config in nodepool Amount of requested CPU needs to be provided as well as other gke data
- cpu_
calculated_ stg_ cfgroup2 - Function to calculate used cpu - based on cpu cycles on cfgroup2 config in nodepool Amount of requested CPU needs to be provided as well as other gke data